Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(912)

Unified Diff: components/sync/protocol/session_specifics.proto

Issue 2921883003: [Sync] Ensure referrer is recorded regardless of policy conversion (Closed)
Patch Set: Tighten Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/sessions/ios/ios_serialized_navigation_driver.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/sync/protocol/session_specifics.proto
diff --git a/components/sync/protocol/session_specifics.proto b/components/sync/protocol/session_specifics.proto
index 622309b5a7e7cd7097bf3fb25739810f8a461e9b..72b7e02f2c2bdedf23cc49803113eb6515e8b800 100644
--- a/components/sync/protocol/session_specifics.proto
+++ b/components/sync/protocol/session_specifics.proto
@@ -134,8 +134,8 @@ message TabNavigation {
// The status code from the last navigation.
optional int32 http_status_code = 20;
- // Referrer policy. Old, broken value.
- optional int32 obsolete_referrer_policy = 21 [default = 1];
+ // Referrer policy. Old, broken value. Deprecated in M61.
+ optional int32 obsolete_referrer_policy = 21 [deprecated = true];
// True if created from restored navigation entry that hasn't been loaded.
optional bool is_restored = 22;
// The chain of redirections for this navigation, from the original URL
« no previous file with comments | « components/sessions/ios/ios_serialized_navigation_driver.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698